==> pydecotools-0.1.0.tar.gz: pydecotools-0.1.0/README.md <==
# pydecotools

![[CI](https://github.com/ilotoki0804/pydecotools/workflows/ci/badge.svg?branch=main)](https://github.com/ilotoki0804/pydecotools/actions?workflow=ci)
[![Codecov](https://codecov.io/gh/ilotoki0804/pydecotools/branch/main/graph/badge.svg)](https://codecov.io/gh/ilotoki0804/pydecotools)
[![Maintainability](https://api.codeclimate.com/v1/badges/d96cc9a1841a819cd4f5/maintainability)](https://codeclimate.com/github/ilotoki0804/pydecotools/maintainability)
[![Code Climate technical debt](https://img.shields.io/codeclimate/tech-debt/ilotoki0804/pydecotools)](https://codeclimate.com/github/ilotoki0804/pydecotools)
[![Read the Docs](https://img.shields.io/readthedocs/pydecotools/latest?label=Read%20the%20Docs)](https://pydecotools.readthedocs.io/en/latest/index.html)

**The collection of decorator utilities.**

## Summary

This library offers a selection of tools that can be used advantageously when employing decorators.

<!-- ## Motivation -->

<!-- ## Acknowledgments

I refer to other important sources of information as comments in the specific
files. Thanks, everyone, for keeping open discussions on internet. -->

## How to use this repository

The `documentation` pages explain how to use this template for your projects
and the implementation details adopted here.
<!-- The documentation pages also serve
to demonstrate how to compile documentation with Sphinx and deploy it online
with `ReadTheDocs`. -->

## Issues and Discussions

As usual for any GitHub-based project, raise an `issue` if you find any bug or
want to suggest an improvement, or open a `discussion` if you want to discuss
or chat :wink:

## Projects using pydecotools

<!-- Below, a list of the projects using this repository: -->

Currently, none of the projects using this repository.

If you use this repository as a reference for your works, let me know, so I
list your work above, as well.

## Changelog

### v0.1.0

* Initial release

==> pydecotools-0.2.1.tar.gz: pydecotools-0.2.1/README.md <==
# pydecotools

<!-- ![[CI](https://github.com/ilotoki0804/pydecotools/workflows/ci/badge.svg?branch=main)](https://github.com/ilotoki0804/pydecotools/actions?workflow=ci)
[![Codecov](https://codecov.io/gh/ilotoki0804/pydecotools/branch/main/graph/badge.svg)](https://codecov.io/gh/ilotoki0804/pydecotools)
[![Maintainability](https://api.codeclimate.com/v1/badges/d96cc9a1841a819cd4f5/maintainability)](https://codeclimate.com/github/ilotoki0804/pydecotools/maintainability)
[![Code Climate technical debt](https://img.shields.io/codeclimate/tech-debt/ilotoki0804/pydecotools)](https://codeclimate.com/github/ilotoki0804/pydecotools)
[![Read the Docs](https://img.shields.io/readthedocs/pydecotools/latest?label=Read%20the%20Docs)](https://pydecotools.readthedocs.io/en/latest/index.html) -->

**The collection of decorator utilities.**

## Summary

This library offers tools that can be used when employing decorators.

<!-- ## Motivation -->

<!-- ## Acknowledgments

I refer to other important sources of information as comments in the specific
files. Thanks, everyone, for keeping open discussions on internet. -->

## How to use this repository

The markdown file in `docs` directory explain how to use this library for your projects
and the implementation details adopted here.
<!-- The documentation pages also serve
to demonstrate how to compile documentation with Sphinx and deploy it online
with `ReadTheDocs`. -->

## Issues and Discussions

As usual for any GitHub-based project, raise an `issue` if you find any bug or
want to suggest an improvement, or open a `discussion` if you want to discuss
or chat :wink:

## Projects using pydecotools

<!-- Below, a list of the projects using this repository: -->

Currently, none of the projects using this repository.

If you use this repository as a reference for your works, let me know, so I
list your work above<!--, as well-->.

## Copyright

[joaomcteixeira's python-project-skeleton](https://github.com/joaomcteixeira/python-project-skeleton) is used for this project.

## Changelog

### v0.2.1 (01/01/2023)

* Make islice usable

### v0.2.0 (12/17/2023)

* Refine README
* Make smart_partial internal
* Remove github actions

### v0.1.0 (12/17/2023)

* Initial release
